@@ -298,7 +298,9 @@ class AlistFuseOperations(Operations):
             except KeyError:
                 file, preread = self._fh_to_file[fh] = self._open(path, offset)
             cache_size = len(preread)
-            if offset < cache_size:
+            if file is None:
+                return preread[offset:offset+size]
+            elif offset < cache_size:
                 if offset + size <= cache_size:
                     return preread[offset:offset+size]
                 elif file is not None:
